## SCENARIO 1: Lines: None; Key column: NA

### INPUTS

#### GROUP 1: Log

# | Line
--- | ---
1 | Log line 1

####

#### GROUP 2: Scalars

# | Delimiter | Column#
--- | --- | ---
1 | , | 9

####

#### GROUP 3: Lines: Empty

### OUTPUTS

#### GROUP 1: Log

# | #Lines | Date Offset | Text
--- | --- | --- | ---
1 | 2 | IN [0,2000]: 718.025 | LIKE /.*: File .*examples-colgroup-ut_group.csv, delimiter ',', column 9/: 2022-10-08 11:12:01: File C:-Users-Brend-OneDrive-Documents-GitHub-trapit_python_tester-examples-colgroup-ut_group.csv, delimiter ',', column 9

#### 0 failed of 1: SUCCESS

#### GROUP 2: listAsIs

# | #Instances
--- | ---
1 | 0

#### 0 failed of 1: SUCCESS

#### GROUP 3: sortByKey: Empty as expected: SUCCESS

#### GROUP 4: sortByValue: Empty as expected: SUCCESS

## 0 failed of 4: SUCCESS